@@ -15,7 +15,12 @@
  * limitations under the License.
  */
 module.exports = {
-  extends: [require.resolve('@umijs/fabric/dist/eslint')],
+  extends: [
+    require.resolve('@umijs/fabric/dist/eslint'),
+    'plugin:import/errors',
+    'plugin:import/warnings',
+  ],
+  plugins: ['simple-import-sort'],
   globals: {
     ANT_DESIGN_PRO_ONLY_DO_NOT_USE_IN_YOUR_PRODUCTION: true,
     page: true,
@@ -23,5 +28,27 @@ module.exports = {
   },
   rules: {
     '@typescript-eslint/naming-convention': 'off',
+    'import/no-unresolved': [2, { ignore: ['^@/', '^umi/', '^@@/'] }],
+    'sort-imports': 'off',
+    'import/order': 'off',
+    'simple-import-sort/imports': 'error',
+    'simple-import-sort/exports': 'error',
   },
+  settings: {
+    'import/resolver': {
+      node: {
+        path: ['src'],
+        extensions: ['.js', '.ts', '.tsx', '.jsx'],
+      },
+    },
+  },
+  overrides: [
+    {
+      files: 'server/**/*.js',
+      env: { node: true },
+      rules: {
+        'import/order': ['error', { 'newlines-between': 'always' }],
+      },
+    },
+  ],
 };
