@@ -31,7 +31,7 @@ export default {
   'component.plugin.serverless': 'Serverless',
   'component.plugin.observability': 'Observability',
   'component.plugin.other': 'Other',
-
+  'component.plugin.all': 'All',
   // cors
   'component.pluginForm.cors.allow_origins.tooltip':
     'Which Origins is allowed to enable CORS, format as：scheme://host:port, for example: https://somehost.com:8081. Multiple origin use , to split. When allow_credential is false, you can use * to indicate allow any origin. you also can allow all any origins forcefully using ** even already enable allow_credential, but it will bring some security risks.',
@@ -65,6 +65,10 @@ export default {
   // api-breaker
   'component.pluginForm.api-breaker.break_response_code.tooltip':
     'Return error code when unhealthy.',
+  'component.pluginForm.api-breaker.break_response_body.tooltip':
+    'Return body of the response message when upstream is unhealthy.',
+  'component.pluginForm.api-breaker.break_response_headers.tooltip':
+    'Return headers when unhealthy.',
   'component.pluginForm.api-breaker.max_breaker_sec.tooltip': 'Maximum breaker time(seconds).',
   'component.pluginForm.api-breaker.unhealthy.http_statuses.tooltip':
     'Status codes when unhealthy.',
