@@ -15,5 +15,5 @@
  * limitations under the License.
  */
 export default {
-  'component.rawDataEditor.tip': "Şu anda düzenleme modunu desteklemiyor",
+  'component.rawDataEditor.tip': 'Şu anda düzenleme modunu desteklemiyor',
 };
