@@ -14,15 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-import React, { useEffect, useRef, useState } from 'react';
-import { PageHeaderWrapper } from '@ant-design/pro-layout';
-import { history, useIntl } from 'umi';
-import ProTable from '@ant-design/pro-table';
-import type { ActionType, ProColumns } from '@ant-design/pro-table';
-import { Button, notification, Popconfirm, Select, Space, Tag } from 'antd';
 import { PlusOutlined } from '@ant-design/icons';
+import { PageHeaderWrapper } from '@ant-design/pro-layout';
+import type { ActionType, ProColumns } from '@ant-design/pro-table';
+import ProTable from '@ant-design/pro-table';
+import { Button, notification, Popconfirm, Select, Space, Tag } from 'antd';
+import React, { useEffect, useRef, useState } from 'react';
+import { history, useIntl } from 'umi';
+
 import usePagination from '@/hooks/usePagination';
-import { fetchList, remove, fetchLabelList } from './service';
+
+import { fetchLabelList, fetchList, remove } from './service';
 
 const Page: React.FC = () => {
   const ref = useRef<ActionType>();
