@@ -14,60 +14,58 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-import type { ReactNode } from 'react';
-import React, { useRef, useEffect, useState } from 'react';
+import { DownOutlined, ExportOutlined, ImportOutlined, PlusOutlined } from '@ant-design/icons';
 import { PageHeaderWrapper } from '@ant-design/pro-layout';
+import type { ActionType, ProColumns } from '@ant-design/pro-table';
 import ProTable from '@ant-design/pro-table';
-import type { ProColumns, ActionType } from '@ant-design/pro-table';
+import { useThrottleFn } from 'ahooks';
 import {
   Button,
-  Popconfirm,
-  notification,
-  Tag,
-  Space,
-  Select,
-  Radio,
-  Form,
-  Upload,
-  Modal,
-  Divider,
-  Menu,
   Dropdown,
+  Form,
+  Menu,
+  Modal,
+  notification,
+  Popconfirm,
+  Radio,
+  Select,
+  Space,
+  Table,
+  Tag,
   Tooltip,
 } from 'antd';
-import { history, useIntl } from 'umi';
-import usePagination from '@/hooks/usePagination';
-import { PlusOutlined, ExportOutlined, ImportOutlined, DownOutlined } from '@ant-design/icons';
+import { saveAs } from 'file-saver';
 import { js_beautify } from 'js-beautify';
 import yaml from 'js-yaml';
-import moment from 'moment';
-import { saveAs } from 'file-saver';
 import { omit } from 'lodash';
+import moment from 'moment';
+import type { ReactNode } from 'react';
+import React, { useEffect, useRef, useState } from 'react';
+import { history, useIntl } from 'umi';
 
+import { RawDataEditor } from '@/components/RawDataEditor';
 import { DELETE_FIELDS } from '@/constants';
 import { timestampToLocaleString } from '@/helpers';
-import type { RcFile } from 'antd/lib/upload';
+import usePagination from '@/hooks/usePagination';
+import DataLoaderImport from '@/pages/Route/components/DataLoader/Import';
 
+import { DebugDrawView } from './components/DebugViews';
+import { EXPORT_FILE_MIME_TYPE_SUPPORTED } from './constants';
 import {
-  update,
   create,
+  exportRoutes,
+  fetchLabelList,
   fetchList,
   remove,
-  fetchLabelList,
+  update,
   updateRouteStatus,
-  exportRoutes,
-  importRoutes,
 } from './service';
-import { DebugDrawView } from './components/DebugViews';
-import { RawDataEditor } from '@/components/RawDataEditor';
-import { EXPORT_FILE_MIME_TYPE_SUPPORTED } from './constants';
 
 const { OptGroup, Option } = Select;
 
 const Page: React.FC = () => {
   const ref = useRef<ActionType>();
   const { formatMessage } = useIntl();
-  const [exportFileTypeForm] = Form.useForm();
 
   enum RouteStatus {
     Offline = 0,
@@ -81,14 +79,14 @@ const Page: React.FC = () => {
 
   const [labelList, setLabelList] = useState<LabelList>({});
   const [selectedRowKeys, setSelectedRowKeys] = useState<string[]>([]);
-  const [uploadFileList, setUploadFileList] = useState<RcFile[]>([]);
-  const [showImportModal, setShowImportModal] = useState(false);
+  const [showImportDrawer, setShowImportDrawer] = useState(false);
   const [visible, setVisible] = useState(false);
   const [rawData, setRawData] = useState<Record<string, any>>({});
   const [id, setId] = useState('');
   const [editorMode, setEditorMode] = useState<'create' | 'update'>('create');
   const { paginationConfig, savePageList, checkPageList } = usePagination();
   const [debugDrawVisible, setDebugDrawVisible] = useState(false);
+  const [routeId, setRouteId] = useState<string>('');
 
   useEffect(() => {
     fetchLabelList().then(setLabelList);
@@ -100,6 +98,8 @@ const Page: React.FC = () => {
       setSelectedRowKeys(currentSelectKeys);
     },
     preserveSelectedRowKeys: true,
+    selections: [Table.SELECTION_ALL, Table.SELECTION_INVERT, Table.SELECTION_NONE],
+    defaultSelectedRowKeys: [1],
   };
 
   const handleTableActionSuccessResponse = (msgTip: string) => {
@@ -110,18 +110,25 @@ const Page: React.FC = () => {
     checkPageList(ref);
   };
 
-  const handlePublishOffline = (rid: string, status: RouteModule.RouteStatus) => {
-    updateRouteStatus(rid, status).then(() => {
-      const actionName = status
-        ? formatMessage({ id: 'page.route.publish' })
-        : formatMessage({ id: 'page.route.offline' });
-      handleTableActionSuccessResponse(
-        `${actionName} ${formatMessage({
-          id: 'menu.routes',
-        })} ${formatMessage({ id: 'component.status.success' })}`,
-      );
-    });
-  };
+  const { run: handlePublishOffline } = useThrottleFn(
+    (rid: string, status: RouteModule.RouteStatus) => {
+      setRouteId(rid);
+      updateRouteStatus(rid, status)
+        .then(() => {
+          const actionName = status
+            ? formatMessage({ id: 'page.route.publish' })
+            : formatMessage({ id: 'page.route.offline' });
+          handleTableActionSuccessResponse(
+            `${actionName} ${formatMessage({
+              id: 'menu.routes',
+            })} ${formatMessage({ id: 'component.status.success' })}`,
+          );
+        })
+        .finally(() => {
+          setRouteId('');
+        });
+    },
+  );
 
   const handleExport = (exportFileType: ExportFileType) => {
     exportRoutes(selectedRowKeys.join(',')).then((resp) => {
@@ -154,26 +161,6 @@ const Page: React.FC = () => {
     });
   };
 
-  const handleImport = () => {
-    const formData = new FormData();
-    if (!uploadFileList[0]) {
-      notification.warn({
-        message: formatMessage({ id: 'page.route.button.selectFile' }),
-      });
-      return;
-    }
-    formData.append('file', uploadFileList[0]);
-
-    importRoutes(formData).then(() => {
-      handleTableActionSuccessResponse(
-        `${formatMessage({ id: 'page.route.button.importOpenApi' })} ${formatMessage({
-          id: 'component.status.success',
-        })}`,
-      );
-      setShowImportModal(false);
-    });
-  };
-
   const ListToolbar = () => {
     const tools = [
       {
@@ -193,11 +180,10 @@ const Page: React.FC = () => {
         },
       },
       {
-        name: formatMessage({ id: 'page.route.button.importOpenApi' }),
+        name: formatMessage({ id: 'page.route.data_loader.import' }),
         icon: <ImportOutlined />,
         onClick: () => {
-          setUploadFileList([]);
-          setShowImportModal(true);
+          setShowImportDrawer(true);
         },
       },
     ];
@@ -292,6 +278,7 @@ const Page: React.FC = () => {
   };
 
   const ListFooter: React.FC = () => {
+    const [exportFileTypeForm] = Form.useForm();
     return (
       <Popconfirm
         title={
@@ -331,7 +318,7 @@ const Page: React.FC = () => {
     {
       title: formatMessage({ id: 'component.global.name' }),
       dataIndex: 'name',
-      fixed: 'left',
+      width: 150,
     },
     {
       title: formatMessage({ id: 'component.global.id' }),
@@ -347,8 +334,8 @@ const Page: React.FC = () => {
         const list = record.hosts || (record.host && [record.host]) || [];
 
         return list.map((item) => (
-          <Tooltip placement="topLeft" title={item}>
-            <Tag key={item} color="geekblue" style={tagStyle}>
+          <Tooltip key={item} placement="topLeft" title={item}>
+            <Tag color="geekblue" style={tagStyle}>
               {item}
             </Tag>
           </Tooltip>
@@ -363,8 +350,8 @@ const Page: React.FC = () => {
         const list = record.uris || (record.uri && [record.uri]) || [];
 
         return list.map((item) => (
-          <Tooltip placement="topLeft" title={item}>
-            <Tag key={item} color="geekblue" style={tagStyle}>
+          <Tooltip key={item} placement="topLeft" title={item}>
+            <Tag color="geekblue" style={tagStyle}>
               {item}
             </Tag>
           </Tooltip>
@@ -391,6 +378,8 @@ const Page: React.FC = () => {
           ));
       },
       renderFormItem: (_, { type }) => {
+        console.log(labelList);
+
         if (type === 'form') {
           return null;
         }
@@ -523,6 +512,7 @@ const Page: React.FC = () => {
                 onClick={() => {
                   handlePublishOffline(record.id, RouteStatus.Publish);
                 }}
+                loading={record.id === routeId}
               >
                 {formatMessage({ id: 'page.route.publish' })}
               </Button>
@@ -539,7 +529,12 @@ const Page: React.FC = () => {
                 okText={formatMessage({ id: 'component.global.confirm' })}
                 cancelText={formatMessage({ id: 'component.global.cancel' })}
               >
-                <Button type="primary" danger disabled={Boolean(!record.status)}>
+                <Button
+                  type="primary"
+                  danger
+                  disabled={Boolean(!record.status)}
+                  loading={record.id === routeId}
+                >
                   {formatMessage({ id: 'page.route.offline' })}
                 </Button>
               </Popconfirm>
@@ -567,6 +562,33 @@ const Page: React.FC = () => {
         actionRef={ref}
         rowKey="id"
         columns={columns}
+        rowSelection={rowSelection}
+        tableAlertRender={() => (
+          <Space size={24}>
+            <span>
+              {formatMessage({ id: 'page.route.chosen' })} {selectedRowKeys.length}{' '}
+              {formatMessage({ id: 'page.route.item' })}
+            </span>
+          </Space>
+        )}
+        tableAlertOptionRender={() => {
+          return (
+            <Space size={16}>
+              <Button
+                onClick={async () => {
+                  await remove(selectedRowKeys).then(() => {
+                    handleTableActionSuccessResponse(
+                      `${formatMessage({ id: 'component.global.delete.routes.success' })}`,
+                    );
+                  });
+                  ref.current?.reloadAndRest?.();
+                }}
+              >
+                {formatMessage({ id: 'page.route.batchDeletion' })}
+              </Button>
+            </Space>
+          );
+        }}
         request={fetchList}
         pagination={{
           onChange: (page, pageSize?) => savePageList(page, pageSize),
@@ -584,9 +606,7 @@ const Page: React.FC = () => {
           </Button>,
           <ListToolbar />,
         ]}
-        rowSelection={rowSelection}
         footer={() => <ListFooter />}
-        tableAlertRender={false}
         scroll={{ x: 1300 }}
       />
       <DebugDrawView
@@ -612,45 +632,14 @@ const Page: React.FC = () => {
           );
         }}
       />
-      <Modal
-        title={formatMessage({ id: 'page.route.button.importOpenApi' })}
-        visible={showImportModal}
-        okText={formatMessage({ id: 'component.global.confirm' })}
-        onOk={handleImport}
-        onCancel={() => {
-          setShowImportModal(false);
-        }}
-      >
-        <Upload
-          fileList={uploadFileList as any}
-          beforeUpload={(file) => {
-            setUploadFileList([file]);
-            return false;
+      {showImportDrawer && (
+        <DataLoaderImport
+          onClose={(finish) => {
+            if (finish) checkPageList(ref);
+            setShowImportDrawer(false);
           }}
-          onRemove={() => {
-            setUploadFileList([]);
-          }}
-        >
-          <Button type="primary" icon={<ImportOutlined />}>
-            {formatMessage({ id: 'page.route.button.selectFile' })}
-          </Button>
-        </Upload>
-        <Divider />
-        <div>
-          <p>{formatMessage({ id: 'page.route.instructions' })}:</p>
-          <p>
-            <a
-              href="https://apisix.apache.org/docs/dashboard/IMPORT_OPENAPI_USER_GUIDE"
-              target="_blank"
-            >
-              1.{' '}
-              {`${formatMessage({ id: 'page.route.import' })} ${formatMessage({
-                id: 'page.route.instructions',
-              })}`}
-            </a>
-          </p>
-        </div>
-      </Modal>
+        />
+      )}
     </PageHeaderWrapper>
   );
 };
